@@ -10,8 +10,10 @@ def NX(x,lengths):
 		if curr_sum >= stop:
 			return length
 
-def decide_scaffolding_procedure(contigs, param):
-	lengths = map(lambda x: len(contigs[x]), contigs)
+def decide_scaffolding_procedure(Scaffolds,small_scaffolds, param):
+	lengths_long = map(lambda x: Scaffolds[x].s_length, Scaffolds)
+	lengths_short = map(lambda x: small_scaffolds[x].s_length, small_scaffolds)
+	lengths = lengths_long + lengths_short
 	N60 = NX(60,lengths)
 	if N60 < param.ins_size_threshold:
 		param.no_score = True
